﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace WPF_xamDockManager_dockingIndicators
{
    public enum DockingSide
    {
        /// <summary>Panes can only be docked on the LEFT side of the main window.</summary>
        Left,
        /// <summary>Panes can only be docked on the RIGHT side of the main window.</summary>
        Right
    }

    public class SampWindow1ViewModel : INotifyPropertyChanged
    {
        private DockingSide _dockingSide;

        public event PropertyChangedEventHandler PropertyChanged;

        public SampWindow1ViewModel()
        {
            _dockingSide = DockingSide.Right;
        }

        /// <summary>Defines on which side of the main window panes can be docked.</summary>
        public DockingSide DockingSide
        {
            get { return _dockingSide; }
            set
            {
                if (_dockingSide != value)
                {
                    _dockingSide = value;
                    OnPropertyChanged("DockingSide");
                    //OnPropertyChanged("AllowDockingLeft");
                    //OnPropertyChanged("AllowDockingRight");
                }
            }
        }

        /// <summary>Gets whether panes can be docked on the left side of the main window.</summary>
        public bool AllowDockingLeft
        {
            get
            {
                return _dockingSide == DockingSide.Left;
            }
        }

        /// <summary>Gets whether panes can be docked on the right side of the main window.</summary>
        public bool AllowDockingRight
        {
            get
            {
                return _dockingSide == DockingSide.Right;
            }
        }

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
